@@ -4,6 +4,7 @@ from datetime import timedelta
 from elementtree.ElementTree import ElementTree
 from urllib2 import urlopen
 
+from django.template.defaultfilters import slugify
 from django.conf import settings as conf
 
 from django import template
@@ -23,9 +24,17 @@ def tla_list(context):
     """
     """
     request = context['request']
-    url = 'http://www.text-link-ads.com/xml.php?inventory_key=' +  conf.KEY_TLA + '&referer=' + request.META.get('REQUEST_URI', request.META.get('PATH_INFO', '/'))
-    agent = '&user_agent=' + request.META['HTTP_USER_AGENT']
-    links = ElementTree.parse(ElementTree(),urlopen(url+agent))
+    #ref = request.META.get('REQUEST_URI', request.META.get('PATH_INFO', '/'))
+    ref = "/" + slugify(request.META.get('REQUEST_URI', request.META.get('PATH_INFO', '/')))
+    url = 'http://www.text-link-ads.com/xml.php?inventory_key=' +  conf.KEY_TLA + '&referer=' + ref
+    try:
+        agent = '&user_agent=' + request.META['HTTP_USER_AGENT']
+    except:
+        agent = '&user_agent=Mozilla/5.0'
+    try:
+        links = ElementTree.parse(ElementTree(),urlopen(url+agent))
+    except:
+        links = None
 
     return {
         'links': [ Link(link) for link in links ]
