@@ -92,7 +92,7 @@ class PostDetailView(DetailView):
     def get_context_data(self, **kwargs):
         context = super(PostDetailView, self).get_context_data(**kwargs)
         comments = mymodels.Comments.objects.filter(
-            thread_id=self.obj.thread_id)
+            thread_id=self.obj.thread_id, thread_id__isnull=False)
         context.update({
             'comments': comments,
         })
